@@ -1,29 +1,33 @@
+# frozen_string_literal: true
+
+require 'method_source'
+
 class Pry
   class CodeFile
-    DEFAULT_EXT = '.rb'
+    DEFAULT_EXT = '.rb'.freeze
 
     # List of all supported languages.
     # @return [Hash]
     EXTENSIONS = {
-      %w(.py)        => :python,
-      %w(.js)        => :javascript,
-      %w(.css)       => :css,
-      %w(.xml)       => :xml,
-      %w(.php)       => :php,
-      %w(.html)      => :html,
-      %w(.diff)      => :diff,
-      %w(.java)      => :java,
-      %w(.json)      => :json,
-      %w(.c .h)      => :c,
-      %w(.rhtml)     => :rhtml,
-      %w(.yaml .yml) => :yaml,
-      %w(.cpp .hpp .cc .h .cxx) => :cpp,
-      %w(.rb .ru .irbrc .gemspec .pryrc .rake) => :ruby,
-    }
+      %w[.py] => :python,
+      %w[.js] => :javascript,
+      %w[.css] => :css,
+      %w[.xml] => :xml,
+      %w[.php] => :php,
+      %w[.html] => :html,
+      %w[.diff] => :diff,
+      %w[.java] => :java,
+      %w[.json] => :json,
+      %w[.c .h] => :c,
+      %w[.rhtml] => :rhtml,
+      %w[.yaml .yml] => :yaml,
+      %w[.cpp .hpp .cc .h .cxx] => :cpp,
+      %w[.rb .ru .irbrc .gemspec .pryrc .rake] => :ruby
+    }.freeze
 
     FILES = {
-      %w(Gemfile Rakefile Guardfile Capfile) => :ruby
-    }
+      %w[Gemfile Rakefile Guardfile Capfile] => :ruby
+    }.freeze
 
     # Store the current working directory. This allows show-source etc. to work if
     # your process has changed directory since boot. [Issue #675]
@@ -58,16 +62,16 @@ class Pry
     #   readable for some reason.
     # @return [String] absolute path for the given `filename`.
     def abs_path
-      code_path.detect { |path| readable?(path) } or
-        raise MethodSource::SourceNotFoundError,
-              "Cannot open #{ @filename.inspect } for reading."
+      code_path.detect { |path| readable?(path) } ||
+        raise(MethodSource::SourceNotFoundError,
+              "Cannot open #{@filename.inspect} for reading.")
     end
 
     # @param [String] path
     # @return [Boolean] if the path, with or without the default ext,
     #   is a readable file then `true`, otherwise `false`.
     def readable?(path)
-      File.readable?(path) && !File.directory?(path) or
+      File.readable?(path) && !File.directory?(path) ||
         File.readable?(path << DEFAULT_EXT)
     end
 
@@ -80,8 +84,8 @@ class Pry
     # @param [String] filename
     # @param [Symbol] default (:unknown) the file type to assume if none could be
     #   detected.
-    # @return [Symbol, nil] The CodeRay type of a file from its extension, or
-    #   `nil` if `:unknown`.
+    # @return [Symbol, nil] The SyntaxHighlighter type of a file from its
+    #   extension, or `nil` if `:unknown`.
     def type_from_filename(filename, default = :unknown)
       _, @code_type = EXTENSIONS.find do |k, _|
         k.any? { |ext| ext == File.extname(filename) }
