@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 class Pry
   class REPL
     extend Pry::Forwardable
@@ -19,13 +21,11 @@ class Pry
     # @option options [Object] :target The initial target of the session.
     def initialize(pry, options = {})
       @pry    = pry
-      @indent = Pry::Indent.new
+      @indent = Pry::Indent.new(pry)
 
       @readline_output = nil
 
-      if options[:target]
-        @pry.push_binding options[:target]
-      end
+      @pry.push_binding options[:target] if options[:target]
     end
 
     # Start the read-eval-print loop.
@@ -47,10 +47,10 @@ class Pry
     def prologue
       pry.exec_hook :before_session, pry.output, pry.current_binding, pry
 
+      return unless pry.config.correct_indent
+
       # Clear the line before starting Pry. This fixes issue #566.
-      if pry.config.correct_indent
-        Kernel.print(Helpers::Platform.windows_ansi? ? "\e[0F" : "\e[0G")
-      end
+      output.print(Helpers::Platform.windows_ansi? ? "\e[0F" : "\e[0G")
     end
 
     # The actual read-eval-print loop.
@@ -98,13 +98,15 @@ class Pry
       val = read_line("#{current_prompt}#{indentation}")
 
       # Return nil for EOF, :no_more_input for error, or :control_c for <Ctrl-C>
-      return val unless String === val
+      return val unless val.is_a?(String)
 
-      if pry.config.auto_indent
+      if pry.config.auto_indent && !input_multiline?
         original_val = "#{indentation}#{val}"
         indented_val = @indent.indent(val)
 
-        if output.tty? && pry.config.correct_indent && Pry::Helpers::BaseHelpers.use_ansi_codes?
+        if output.tty? &&
+           pry.config.correct_indent &&
+           Pry::Helpers::BaseHelpers.use_ansi_codes?
           output.print @indent.correct_indentation(
             current_prompt,
             indented_val,
@@ -130,7 +132,7 @@ class Pry
         yield
       rescue EOFError
         pry.config.input = Pry.config.input
-        if !should_retry
+        unless should_retry
           output.puts "Error: Pry ran out of things to read from! " \
             "Attempting to break out of REPL."
           return :no_more_input
@@ -139,8 +141,7 @@ class Pry
         retry
 
       # Handle <Ctrl+C> like Bash: empty the current input buffer, but don't
-      # quit.  This is only for MRI 1.9; other versions of Ruby don't let you
-      # send Interrupt from within Readline.
+      # quit.
       rescue Interrupt
         return :control_c
 
@@ -151,9 +152,7 @@ class Pry
         puts "Error: #{e.message}"
         output.puts e.backtrace
         exception_count += 1
-        if exception_count < 5
-          retry
-        end
+        retry if exception_count < 5
         puts "FATAL: Pry failed to get user input using `#{input}`."
         puts "To fix this you may be able to pass input and output file " \
           "descriptors to pry directly. e.g."
@@ -180,17 +179,48 @@ class Pry
           end
         end
 
-        if readline_available?
+        if reline_available?
+          Reline.output_modifier_proc = lambda do |text, _|
+            if pry.color
+              SyntaxHighlighter.highlight(text)
+            else
+              text
+            end
+          end
+
+          if pry.config.auto_indent
+            Reline.auto_indent_proc = lambda do |lines, line_index, _byte_ptr, _newline|
+              if line_index == 0
+                0
+              else
+                pry_indentation = Pry::Indent.new
+                pry_indentation.indent(lines.join("\n"))
+                pry_indentation.last_indent_level.length
+              end
+            end
+          end
+        end
+
+        if input_multiline?
+          input_readmultiline(current_prompt, false)
+        elsif readline_available?
           set_readline_output
           input_readline(current_prompt, false) # false since we'll add it manually
         elsif coolline_available?
           input_readline(current_prompt)
+        elsif input.method(:readline).arity == 1
+          input_readline(current_prompt)
         else
-          if input.method(:readline).arity == 1
-            input_readline(current_prompt)
-          else
-            input_readline
-          end
+          input_readline
+        end
+      end
+    end
+
+    def input_readmultiline(*args)
+      Pry::InputLock.for(:all).interruptible_region do
+        input.readmultiline(*args) do |multiline_input|
+          Pry.commands.find_command(multiline_input) ||
+            (complete_expression?(multiline_input) && !Reline::IOGate.in_pasting?)
         end
       end
     end
@@ -201,6 +231,14 @@ class Pry
       end
     end
 
+    def input_multiline?
+      !!pry.config.multiline && reline_available?
+    end
+
+    def reline_available?
+      defined?(Reline) && input == Reline
+    end
+
     def readline_available?
       defined?(Readline) && input == Readline
     end
@@ -209,6 +247,20 @@ class Pry
       defined?(Coolline) && input.is_a?(Coolline)
     end
 
+    def prism_available?
+      @prism_available ||= begin
+        # rubocop:disable Lint/SuppressedException
+        begin
+          require 'prism'
+        rescue LoadError
+        end
+        # rubocop:enable Lint/SuppressedException
+
+        defined?(Prism::VERSION) &&
+          Gem::Version.new(Prism::VERSION) >= Gem::Version.new('0.25.0')
+      end
+    end
+
     # If `$stdout` is not a tty, it's probably a pipe.
     # @example
     #   # `piping?` returns `false`
@@ -227,8 +279,21 @@ class Pry
     def set_readline_output
       return if @readline_output
 
-      if piping?
-        @readline_output = (Readline.output = Pry.config.output)
+      @readline_output = (Readline.output = Pry.config.output) if piping?
+    end
+
+    UNEXPECTED_TOKENS = %i[unexpected_token_ignore lambda_open].freeze
+
+    def complete_expression?(multiline_input)
+      if prism_available?
+        lex = Prism.lex(multiline_input)
+
+        errors = lex.errors
+        return true if errors.empty?
+
+        errors.any? { |error| UNEXPECTED_TOKENS.include?(error.type) }
+      else
+        Pry::Code.complete_expression?(multiline_input)
       end
     end
 
@@ -247,7 +312,7 @@ class Pry
           # rb-readline doesn't support this method:
           # https://github.com/ConnorAtherton/rb-readline/issues/152
           if Readline.vi_editing_mode?
-            overhang += current_prompt.length - indented_val.length
+            overhang = output.width - current_prompt.size - indented_val.size
           end
         rescue NotImplementedError
           # VI editing mode is unsupported on JRuby.
