@@ -1,4 +1,6 @@
-require_relative '../helper'
+# frozen_string_literal: true
+
+require 'tempfile'
 
 describe "cat" do
   before do
@@ -9,21 +11,23 @@ describe "cat" do
         @pry.update_input_history(nil)
       end
 
-      def last_exception=(e)
-        @pry.last_exception = e
+      def last_exception=(exception)
+        @pry.last_exception = exception
       end
     end
   end
 
   describe "when invoked without arguments" do
     it 'should display an error message' do
-      expect { @t.eval 'cat' }.to raise_error(Pry::CommandError, /Must provide a filename/)
+      expect { @t.eval 'cat' }
+        .to raise_error(Pry::CommandError, /Must provide a filename/)
     end
   end
 
   describe "on receiving a file that does not exist" do
     it 'should display an error message' do
-      expect { @t.eval 'cat supercalifragilicious66' }.to raise_error(StandardError, /Cannot open/)
+      expect { @t.eval 'cat supercalifragilicious66' }
+        .to raise_error(StandardError, /Cannot open/)
     end
   end
 
@@ -56,12 +60,12 @@ describe "cat" do
       @t.insert_nil_input # normally happens when a command is executed
       @t.eval ':hello'
 
-      expect(@t.eval('cat --in 1..3')).to eq unindent(<<-EOS)
+      expect(@t.eval('cat --in 1..3')).to eq(unindent(<<-RANGE))
         1:
           10
         3:
           :hello
-      EOS
+      RANGE
     end
   end
 
@@ -76,20 +80,20 @@ describe "cat" do
     end
 
     it 'cat --ex should display repl code that generated exception' do
-      @t.eval unindent(<<-EOS)
+      @t.eval(unindent(<<-LAST_EXCEPTION))
         begin
           this raises error
         rescue => e
-          _pry_.last_exception = e
+          pry_instance.last_exception = e
         end
-      EOS
+      LAST_EXCEPTION
       expect(@t.eval('cat --ex')).to match(/\d+:(\s*) this raises error/)
     end
 
     it 'cat --ex should correctly display code that generated exception' do
       begin
         @o.broken_method
-      rescue => e
+      rescue StandardError => e
         @t.last_exception = e
       end
       expect(@t.eval('cat --ex')).to match(/this method is broken/)
@@ -135,10 +139,14 @@ describe "cat" do
 
     it 'should show error when backtrace level out of bounds' do
       @t.last_exception = mock_exception('x', 'x', 'x')
-      expect { @t.eval('cat --ex 3') }.to raise_error(Pry::CommandError, /out of bounds/)
+      expect { @t.eval('cat --ex 3') }
+        .to raise_error(Pry::CommandError, /out of bounds/)
     end
 
-    it 'each successive cat --ex should show the next level of backtrace, and going past the final level should return to the first' do
+    it(
+      'each successive cat --ex should show the next level of backtrace, ' \
+      'and going past the final level should return to the first'
+    ) do
       temp_files = []
       3.times do |i|
         temp_files << Tempfile.new(['pry', '.rb'])
