@@ -1,4 +1,4 @@
-require_relative '../helper'
+# frozen_string_literal: true
 
 describe "exit" do
   before { @pry = Pry.new(target: :outer, output: StringIO.new) }
