@@ -43,7 +43,7 @@ describe "hist" do
     @hist.push "cd 2"
 
     @t.eval("hist --replay 0..2")
-    stack = @t.eval("Pad.stack = pry_instance.binding_stack.dup")
+    stack = @t.eval("stack = pry_instance.binding_stack.dup")
     expect(stack.map { |b| b.eval("self") }).to eq [TOPLEVEL_BINDING.eval("self"), 1, 2]
   end
 
@@ -202,7 +202,7 @@ describe "hist" do
       expect(@t.eval('hist')).to match(/1:\shello\n2:\sworld/)
     end
 
-    it "displays all history (including the current sesion) with `--all` switch" do
+    it "displays all history (including the current session) with `--all` switch" do
       @hist.push('goodbye')
       @hist.push('world')
 
