@@ -1,21 +1,18 @@
-require_relative '../helper'
+# frozen_string_literal: true
 
 describe 'Formatting Table' do
   it 'knows about colorized fitting' do
-    t = Pry::Helpers::Table.new %w(hihi), column_count: 1
+    t = Pry::Helpers::Table.new %w[hihi], column_count: 1
     expect(t.fits_on_line?(4)).to eq true
     t.items = []
     expect(t.fits_on_line?(4)).to eq true
 
-    t.items = %w(hi hi)
+    t.items = %w[hi hi]
     expect(t.fits_on_line?(4)).to eq true
     t.column_count = 2
     expect(t.fits_on_line?(4)).to eq false
 
-    t.items = %w(
-      a   ccc
-      bb  dddd
-    ).sort
+    t.items = %w[a ccc bb dddd].sort
     expect(t.fits_on_line?(8)).to eq true
     expect(t.fits_on_line?(7)).to eq false
   end
@@ -25,7 +22,8 @@ describe 'Formatting Table' do
     def try_round_trip(expected)
       things = expected.split(/\s+/).sort
       actual = Pry::Helpers.tablify(things, FAKE_COLUMNS).to_s.strip
-      [expected, actual].each { |e| e.gsub!(/\s+$/, '') }
+      expected = expected.gsub(/\s+$/, '')
+      actual = actual.gsub(/\s+$/, '')
       if actual != expected
         bar = '-' * 25
         puts \
@@ -38,21 +36,21 @@ describe 'Formatting Table' do
     end
 
     it 'should handle a tiny case' do
-      try_round_trip(<<-eot)
+      try_round_trip(<<-TABLE)
 asdf  asfddd  fdass
-      eot
+      TABLE
     end
 
     it 'should handle the basic case' do
-      try_round_trip(<<-eot)
+      try_round_trip(<<-TABLE)
 aadd            ddasffssdad  sdsaadaasd      ssfasaafssd
 adassdfffaasds  f            sdsfasddasfds   ssssdaa
 assfsafsfsds    fsasa        ssdsssafsdasdf
-      eot
+      TABLE
     end
 
     it 'should handle... another basic case' do
-      try_round_trip(<<-EOT)
+      try_round_trip(<<-TABLE)
 aaad            dasaasffaasf    fdasfdfss       safdfdddsasd
 aaadfasassdfff  ddadadassasdf   fddsasadfssdss  sasf
 aaddaafaf       dddasaaaaaa     fdsasad         sddsa
@@ -61,14 +59,14 @@ adasadfaaffds   dsfafdsfdfssda  ffadsfafsaafa   ss
 asddaadaaadfdd  dssdss          ffssfsfafaadss  ssas
 asdsdaa         faadf           fsddfff         ssdfssff
 asfadsssaaad    fasfaafdssd     s
-      EOT
+      TABLE
     end
 
     it 'should handle colors' do
-      try_round_trip(<<-EOT)
+      try_round_trip(<<-TABLE)
 \e[31maaaaaaaaaa\e[0m                      \e[31mccccccccccccccccccccccccccccc\e[0m
 \e[31mbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb\e[0m  \e[31mddddddddddddd\e[0m
-      EOT
+      TABLE
     end
 
     it 'should handle empty input' do
@@ -98,6 +96,6 @@ asfadsssaaad    fasfaafdssd     s
   end
 
   specify 'decide between one-line or indented output' do
-    expect(Pry::Helpers.tablify_or_one_line('head', %w(ing))).to eq "head: ing\n"
+    expect(Pry::Helpers.tablify_or_one_line('head', %w[ing])).to eq "head: ing\n"
   end
 end
