@@ -1,28 +1,28 @@
-require_relative 'helper'
+# frozen_string_literal: true
 
 describe Pry do
   describe "output failsafe" do
-    after do
-      Pry.config.print = Pry::DEFAULT_PRINT
-    end
+    after { Pry.config.print = Pry::Config.new.print }
 
     it "should catch serialization exceptions" do
-      Pry.config.print = lambda { |*a| raise "catch-22" }
+      Pry.config.print = proc { raise "catch-22" }
 
       expect { mock_pry("1") }.to_not raise_error
     end
 
     it "should display serialization exceptions" do
-      Pry.config.print = lambda { |*a| raise "catch-22" }
+      Pry.config.print = proc { raise "catch-22" }
 
       expect(mock_pry("1")).to match(/\(pry\) output error: #<RuntimeError: catch-22>/)
     end
 
     it "should catch errors serializing exceptions" do
-      Pry.config.print = lambda do |*a|
+      Pry.config.print = proc do
         ex = Exception.new("catch-22")
         class << ex
-          def inspect; raise ex; end
+          def inspect
+            raise ex
+          end
         end
         raise ex
       end
@@ -31,7 +31,7 @@ describe Pry do
     end
   end
 
-  describe "DEFAULT_PRINT" do
+  describe "default print" do
     it "should output the right thing" do
       expect(mock_pry("[1]")).to match(/^=> \[1\]/)
     end
@@ -45,7 +45,8 @@ describe Pry do
     end
 
     it "should not be phased by un-inspectable things" do
-      expect(mock_pry("class NastyClass; undef pretty_inspect; end", "NastyClass.new")).to match(/#<.*NastyClass:0x.*?>/)
+      expect(mock_pry("class NastyClass; undef pretty_inspect; end", "NastyClass.new"))
+        .to match(/#<.*NastyClass:0x.*?>/)
     end
 
     it "doesn't leak colour for object literals" do
@@ -76,7 +77,7 @@ describe Pry do
     it "should colorize strings as though they were ruby" do
       pry = Pry.new
       accumulator = StringIO.new
-      colorized   = CodeRay.scan("[1]", :ruby).term
+      colorized = Pry::SyntaxHighlighter.highlight('[1]')
       pry.config.output = accumulator
       pry.config.print.call(accumulator, [1], pry)
       expect(accumulator.string).to eq("=> #{colorized}\n")
@@ -121,7 +122,8 @@ describe Pry do
     it "does not crash pry" do
       old_stdout = $stdout
       pry_eval = pry_tester(binding)
-      expect(pry_eval.eval("$stdout = Class.new { def write(*) end }.new", ":ok")).to eq(:ok)
+      expect(pry_eval.eval("$stdout = Class.new { def write(*) end }.new", ":ok"))
+        .to eq(:ok)
       $stdout = old_stdout
     end
   end
